/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: NoSuchEntityException.java 4821 2009-03-17 17:12:17Z benoitf $
 * --------------------------------------------------------------------------
 */

package javax.ejb;

/**
 * The NoSuchEntityException exception is thrown by an Entity Bean instance to
 * its container to report that the invoked business method or callback method
 * could not be completed because of the underlying entity was removed from the
 * database.<br>
 * This exception may be thrown by the bean class methods that implement the
 * business methods defined in the bean's component interface; and by the
 * ejbLoad and ejbStore methods.
 * @see <a href="http://www.jcp.org/en/jsr/detail?id=318">EJB 3.1 specification</a>
 * @author Florent Benoit
 */
public class NoSuchEntityException extends EJBException {

    /**
     * UID for serialization.
     */
    private static final long serialVersionUID = -4815730078295420703L;

    /**
     * Default constructor : builds an exception with an empty message.
     */
    public NoSuchEntityException() {
        super();
    }

    /**
     * Build an exception with the given message.
     * @param message the given message to use.
     */
    public NoSuchEntityException(final String message) {
        super(message);
    }

    /**
     * Build an exception with the given exception.
     * @param causedByException the cause of this exception.
     */
    public NoSuchEntityException(final Exception causedByException) {
        super(causedByException);
    }
}
